@@ -13,7 +13,7 @@ FGR <- function(formula,data,cause=1,...){
   # }}}
   # {{{ read the data and the design
   call <- match.call()
-  m <- match.call(expand = FALSE)
+  m <- match.call(expand.dots = FALSE)
   if (match("subset",names(call),nomatch=FALSE))
     stop("Subsetting of data is not possible.")
   m <- m[match(c("","formula","data","subset","na.action"),names(m),nomatch = 0)]
@@ -35,7 +35,12 @@ FGR <- function(formula,data,cause=1,...){
   Y <- as.vector(response[,"time"])
   time  <- numeric(length(Y))
   status <- as.vector(response[,"status"])
-  event <-   as.numeric(getEvent(response))
+  if (match("event",colnames(response),nomatch=0)==0){
+    event <- status
+  }
+  else{
+    event <- as.numeric(getEvent(response))
+  }
   # }}}
   # {{{ cause of interest
   states <- getStates(response)
@@ -96,6 +101,8 @@ FGR <- function(formula,data,cause=1,...){
   # }}}
   # {{{ clean up
   out$call <- match.call()
+  if (is.null(out$call$cause))
+    out$call$cause <- cause
   class(out) <- "FGR"
   # }}}
   out
